@@ -24,7 +24,14 @@ where
     W: std::io::Write,
 {
     type Error = std::io::Error;
+    type Mut<'this> = &'this mut Self where Self: 'this;
 
+    #[inline]
+    fn borrow_mut(&mut self) -> Self::Mut<'_> {
+        self
+    }
+
+    #[inline]
     fn write_bytes(&mut self, bytes: &[u8]) -> Result<(), Self::Error> {
         self.inner.write_all(bytes)
     }
